# HL Chemistry - A

The course code for this page is **SCH3UZ**.

## Designing a scientific investigation

### Scope

The scope of an experiment goes at the very beginning of it. It includes a general introduction to the topic of investigation as well as personal interest.

### Research question

The research question of an experiment is a hyper-focused and specific question related to the topic. It contains and asks about the effect of an **independent variable** on a **dependent variable**.

### Background information and hypothesis

!!! note
    This section can instead be placed immediately before the research question depending on the experiment.

In this section, scientific theories are provided to help the reader understand the rationale of the question, the design of the experiment, and data processing measures. If any theoretical/literature values are used, they should be introduced here.

A hypothesis consists of a justified prediction of the expected outcome and should be integrated with any background information.

### Variables

!!! definition
    - The **independent** variable is the variable that is explicitly changed to attempt to affect the dependent variable.
    - The **dependent** variable is the variable that is directly monitored and measured in the experiment and is expected to change if the independent variable changes.
    - **Controlled** variables (also known as "control variables") are variables that should be kept constant so they do not affect the dependent variable.

The independent variable, dependent variable, and any controlled variables should be listed under this section.

### Materials

A list of materials and equipment should be listed here, as well as their precision. If a controlled variable needs to be measured, any instruments that would be used to do so should also be listed here.

### Procedure

A clear, detailed, and concise set of instructions written in *past tense* should be placed in this section as either a numbered list or descriptive paragraph. To reduce confusion, if a numbered list is used, referring directly to numbers should be avoided, and referring to numbers recursively must *never* happen. A procedure must include:

 - a clear, titled, labelled, and annotated diagram
 - instructions for recording data (including for controlled variables)

If necessary, a "setup" section can be added as preparatory steps should not be listed in the main procedure.

### Data collection

Data should be collected in an organised and titled table that should be prepared before the experiment. The data table must include:

 - units with uncertainty, typically in the table header
 - *qualitative* data (quantitative data can be optional in some experiments)
 - repeated data/controlled variables, typically in the title
 - any relevant information should be listed under the title

Only **raw data** prior to any processing or calculations, with the exception of averages, should be present in the data table.

A data table should be as concise as possible, and redundancy should be minimised. In that vein, trial numbers should *not* be recorded unless that data is relevant.

!!! example
    **Table 1: Effect of Fat Content on Sugar Content in Ice Cream**
    
    | Fat Content (g ± 0.1 g) | Sugar Content (g ± 0.1 g) | Notes |
    | --- | --- | --- |
    | 2.0 | 5.1 | - strawberry ice cream |
    | 0.1 | 2.3 | - mint chocolate chip ice cream |

Whenever possible, data tables should *not* span multiple pages. If that is unavoidable, a new title with "…continued" and new column headers must be present at the top of each new page.

### Data processing

A single sample calculation showing all steps should be present and clearly explained. The rest of the data can be processed without describing any steps. A **single** graph may be included if needed.

Some general rules include:

 - units and uncertainties must be present in all calculations
 - simple operations such as averages and conversions (e.g., g to kg) do not need to be explained
 - the graph, if any, should span at least half of the page (ideally the full page) and should directly answer the research question

A final, reorganised, and processed data table should be present here, showing only relevant information.

### Conclusion and evaluation

This section should be free of any new background information or calculations. It should, in sequence:

 - summarise the results of the experiment without connecting it to the hypothesis
 - identify whether the results of the experiment agree or disagree with the hypothesis
 - evaluate 3–5 systematic errors (usually) present in the experiment, both in the procedure and in data collection/processing, in **decreasing** order of impact to the experiment

The evaluation of systematic errors should include:

 - a description of the error
 - how the error affected the data
 - how the error affected the final result
 - how the error can be remedied with available school resources
## 11.1 - Uncertainties and errors in measurement and results

Please see [SL Physics#Uncertainties and errors](/sph3u7/#12-uncertainties-and-errors) for more information.

## 11.2 - Graphical techniques

When plotting a graph:

 - plot the independent variable on the horizontal axis and the dependent variable on the vertical axis
 - label the axes, ensuring that the labels include units
 - choose an appropriate scale for each axis
 - give the graph an appropriate title at the **bottom** in **title case**
 - draw a line of best fit
 - include all uncertainties in the form of error bars
	- if the error bars are too small to see, it should be noted explanation below

### Titles

The title of a graph should clearly indicate what the graph represents under what conditions in **title case**, so that any onlooker should be able to identify the experiment. It should not include "vs." Any legends present should be located under the graph.

??? example
    "Effect of Cat Deaths on Suicides in New Zealand"

### Error bars

Please see [SL Physics#Error bars](/sph3u7/#error-bars) for more information.

### Line of best fit

Please see [SL Physics#Uncertainty of gradient and intercepts](/sph3u7/#uncertainty-of-gradient-and-intercepts) for more information.

## 11.3 - Spectroscopic identification of organic compounds

## 12 - Atomic structure

!!! definition
    - The **effective nuclear charge** ($Z_\text{eff}$) is the net positive charge (attraction to the nucleus) experienced by an electron in an atom.
    - **Electron shielding** describes the decrease in the effective nuclear charge of an electron because of the repulsion of other electrons in lower-energy shells.

**Atomic notation** is used to represent individual atoms or ions. It is written in the form $^M_Z \text{Symbol}^\text{Charge}$, where $M$ is the mass number of the particle and $Z$ is the atomic number of the particle.

!!! example
    - $^1_1 \text{H}^{+}$ is the atomic notation for the most common hydrogen ion.
    - $^{16}_8 \text{O}^{2-}$ is the atomic notation for the most common oxygen ion.
    - $^{20}_{10} \text{Ne}$ is the atomic notation for the most common neon atom.

### Isotopes

Isotopes are atoms of the same element but with different masses, or alternatively, atoms with the same number of protons but with different numbers of neutrons.

**Radioisotopes** are isotopes that are unstable (will spontaneously decay, are radioactive). Unstable atoms **decay** (break down) into one or more different isotopes of a different element. The **half-life** of a radioisotope is the time it takes for 50% of a sample's atoms to decay.

!!! warning
    Radioisotopes are dangerous! They emit radiation, which is not at all good for human health in the vast majority of cases. However, there are also useful applications for radioisotopes today. For example, Cobalt-60 is used in radiation therapy to kill cancer tumours by damaging their DNA.

### Atomic mass

The mass of every atom is represented relative to 1/12th of a carbon-12 atom. This mass is either unitless or expressed in terms of **atomic mass units (amu or u)**. On the periodic table, the **relative atomic mass** ($A_r$) is shown, which is the sum of the masses of each isotope combined with their natural abundance (%abundance).

$$A_r = \text{%abundance}×\text{mass number of isotope}$$
$$m_a = \Sigma A_r$$

When calculating the atomic mass from the graph from a **mass spectrometer**, the sum of the natural abundances of each isotope may not equal 100 or 1 (not in %abundance). In this case, calculation of %abundance will need to be done before solving for $m_a$.

A mass spectrometer may also provide mass in the form of $M/Z$, which represents mass over charge. For the sake of simplicity, $Z=1$, so $M/Z$ represents the mass of a particle.

### Atomic radius

The atomic radius of an atom is the distance from the centre of the nucleus to approximately the outer boundary of the electron shell. This cannot be directly measured by scientists.

### Ionisation energy

The first ionisation energy of an element is the minimum amount of energy required to remove one mole of electrons from one mole of *gaseous* atoms to form a mole of gaseous ions, so that
$$\text{Q}_\text{(g)} \rightarrow \text{Q}_\text{(g)}^+ + \text{e}^-$$

Any subsequent ionisation energies of an element are the minimum amount of energy required to remove one *additional* mole of electrons. For example, the second ionisation energy would involve
$$\text{Q}_\text{(g)}^+ \rightarrow \text{Q}_\text{(g)}^{2+} + \text{e}^-$$

It requires vastly more energy to remove an electron from a filled valence shell compared to an unfilled valence shell.

### Electron affinity

The electron affinity of an atom is the amount of energy **required** or **released** to *add* an electron to a neutral *gaseous* atom to form a negative ion, such that
$$\text{Q}_\text{(g)} + \text{e}^- \rightarrow \text{Q}^-_\text{(g)}$$ 

If energy is released, the atom has a **negative** electron affinity, and will form a stable ion.

If energy is required, the atom has a **positive** electron affinity, and will form an unstable ion (the ion will spontaneously decay).

### Electronegativity

The electronegativity of an atom represents the ability of that atom to attract a pair of electrons in a **covalent bond**. It ranges from $0$ to $4$ on the Pauling scale. As electronegativity increases, the atom more strongly holds on to the electrons in its covalent bond, so the pair of electrons in that bond spend more time around the atom with the higher electronegativity.

### Reactivity

The reactivity of an element is how "willing" it is to give up or gain electrons to fill its valence shell.

The reaction of an **alkali metal** with water always forms a hydroxide and hydrogen gas. For example, lithium reacts with water such that:
$$2\text{Li}_\text{(s)} + 2\text{H}_2\text{O}_\text{(l)} \rightarrow 2\text{LiOH}_\text{(aq)} + \text{H}_{2 (g)}$$

The reaction of a **halogen** with hydrogen gas always forms a hydride. For example, fluorine reacts with hydrogen gas such that:
$$\text{Fl}_\text{(g)} + \text{H}_\text{2 (g)} \rightarrow 2\text{HFl}_\text{(g)}$$

### Models

Please see [SL Physics#Models](/sph3u7/#models) for more information.

### Periodic trends

Some trends in the periodic table include:

 - atomic radius decreases when going across a period and increases when going down a group
 - ionic radius decreases when going across a period for groups 1–13, then sharply increases and then increases for groups 15–17; it increases when going down a group
 - electron affinity increases when going across a period and decreases when going down a group
 - ionisation energy increases when going across a period and decreases when going down a group
 - electronegativity increases when going across a period and decreases when going down a group
 - reactivity of alkali metals increases when going down the group
 - reactivity of halogens decreases when going down the group

When explaining these trends in the periodic table, it is best to use the following basic concepts to build on to larger points.

Across a period, the number of shells occupied by the electrons is the same but the number of protons in the nucleus increases. Therefore,

 - the attraction of each electron to the nucleus (effective nuclear charge) increases as the number of protons increases
 - shielding is unchanged as the number of electrons between the valence electrons and the nucleus is the same

Down a period, the number of shells occupied by the electrons increases, so valence electrons are further from the nucleus. Therefore,

 - the attraction of valence electrons to the nucleus decreases due to the increasing distance
 - shielding increases due to the increasing number of electrons between the valence electrons and the nucleus

!!! example
    To explain why there is a trend of decreasing atomic radius across a period:

    - As the number of protons and electrons increase together, but the number of electron shells does not change, the effective nuclear charge of each electron increases, while the effect of shielding remains unchanged.
    - This increased effective nuclear charge reduces the atomic radius compared to other atoms before it.

## 4.0 - Chemical bonding and structure

A chemical bond consists of the strong electronic interactions of the **valence** electrons between atoms that hold the atoms closer together. This only occurs if the atoms would reduce their potential energy by bonding.

!!! reminder
    - Metal + metal = metallic bond
    - Metal + non-metal = ionic bond
    - Non-metal + non-metal = covalent bond

!!! reminder
    When drawing a Lewis **dot diagram**, covalent bonds must be represented as two adjacent dots. When drawing a Lewis **structure**, covalent bonds must be represented as lines connecting the atoms. 

    If the process stage is required:

    - Electrons destined to be shared must be encircled.
    - Electrons to be transferred must have arrows pointing to their destination.
    - x'es are used to represent additional electrons that have an unknown source.

### Percentage ionic character

Bonding is a spectrum. The percentage ionic character of a chemical bond shows roughly the amount of time valence electrons spend near an atom or ion in a bond. The difference between two elements' electronegativity (ΔEN) indicates how covalent and how ionic the bond **behaves**.

If ΔEN is:

 - less than 0.5, it behaves like a **pure covalent** bond
 - between 0.5 and 1.7, it behaves like a **polar covalent** bond
 - greater than 1.7, it behaves like an **ionic** bond

## 4.1 - Ionic bonding and structure

An ionic bond is the electrostatic attraction between oppositely charged **ions**. Electrons are transferred first, and then the bond forms via the attraction of the now-positive and negative ions. This reduces the potential energy of the ions and therefore increases their stability.

!!! definition
    **Electrostatic attraction** is the force of attraction between opposite charges.

!!! warning
    When expressing ionic bonds in a Lewis dot diagram, ions with charges of the same sign must *never* be placed next to one another.

### Structure of ionic compounds

Ionic compounds are composed of a **lattice structure** (crystalline structure) of ions of alternating charges. A **formula unit** is the lowest ratio of positive to negative ions.

<img src="/resources/images/nacl-lattice.jpeg" width=700>(Source: Kognity)</img>

!!! example
    In sodium chloride, the ratio of positive sodium ions to negative chloride ions is always 1:1, so its formula is NaCl.

In an ionic compound, the number of ions that each ion can touch is referred to as the **coordination number**. It is stated as "(cation)(anion) is (coordination number of cation):(coordination number of anion) coordinated".

!!! example
    In the diagram above, each sodium ion touches six chloride ions, and each chloride ion touches six sodium ions. Therefore, "NaCl is 6:6 coordinated".

## 4.2 - Covalent bonding

A covalent bond is the electrostatic attraction between pairs of valence electrons and nuclei. This causes atoms to "share" electrons instead of gaining or losing them. Covalent bonds form molecules, which in turn form molecular compounds (not covalent compounds).

<img src="/resources/images/covalent-bond.png" width=700>(Source: Kognity)</img>

Whether a covalent bond is **pure** or **polar** indicates how evenly the shared electrons are shared between the atoms.

 - A pure covalent bond has both nuclei attracting the valence electrons fairly evenly, so the difference in electronegativity (ΔEN) is low.
 - A polar covalent bond has both nuclei attracting the valence electrons unevenly, so the ΔEN is high.

### Bonding capacity

The **bonding capacity** of a non-metal describes the number of covalent bonds it can form. This can be calculated via:

1. Finding the number of needed electrons by taking the sum of 8 times the number of atoms. Hydrogen should be multiplied by 2 instead.
2. Finding the number of electrons present by taking the sum of the valence electrons present. Any ions should have electrons added equal to their positive charge as well.

The number of covalent bonds required is then:
$$\frac{\text{needed} - \text{have}}{2}$$

The number of lone pairs (pairs of un-bonded electrons) left over is:
$$\frac{\text{have} - 2 × \text{bonds required}}{2}$$

### Dative covalent bonds

Sometimes, one atom in a covalent bond may contribute both electrons in a shared pair.

## 4.3 - Covalent structures

## 4.4 - Intermolecular forces

## 4.5 - Metallic bonding

## Resources

 - [IB Chemistry Data Booklet](/resources/g11/ib-chemistry-data-booklet.pdf)
 - [IB HL Chemistry Syllabus](/resources/g11/ib-chemistry-syllabus.pdf)
 - [Significant Figures/Digits](/resources/g11/chemistry-sig-figs.pdf)
 - [Error Analysis and Significant Figures (long)](/resources/g11/error-analysis-sig-figs.pdf)
 - [General Guidelines for Writing a Formal Laboratory Report](/resources/g11/lab-report-guidelines.pdf)
 - [Designing an IB Investigation](/resources/g11/designing-investigation.pdf)

